@@ -203,6 +203,8 @@ impl App {
     }
 
     /// Writes the scores to the file specified in [`App::opts`].
+    ///
+    /// Will not write if `[Opts.nowrite`] prevents it.
     pub fn write_scores(&self) -> io::Result<()> {
         if !self.opts.nowrite {
             let new_path = self.opts.input.with_extension("score.json");
@@ -216,22 +218,26 @@ impl App {
     }
 
     /// Adds a [`flashed::Scores`] into an [`App`]
+    ///
+    /// Will not write if `[Opts.reset`] prevents it.
     pub fn add_scores(&mut self, scores: Scores) {
-        for (card, score) in scores.scores {
-            let pos = self.cards().iter().position(|x| x == card.as_ref());
-            if let Some(pos) = pos {
-                self.scores.insert(pos, score);
+        if !self.opts.reset {
+            for (card, score) in scores.scores {
+                let pos = self.cards().iter().position(|x| x == card.as_ref());
+                if let Some(pos) = pos {
+                    self.scores.insert(pos, score);
+                }
             }
-        }
 
-        for (card, due) in scores.dues {
-            let pos = self.cards().iter().position(|x| x == card.as_ref());
-            if let Some(pos) = pos {
-                self.dues.insert(pos, due);
+            for (card, due) in scores.dues {
+                let pos = self.cards().iter().position(|x| x == card.as_ref());
+                if let Some(pos) = pos {
+                    self.dues.insert(pos, due);
+                }
             }
-        }
 
-        self.retain_undue();
+            self.retain_undue();
+        }
     }
 
     /// Reads the scores from the file in [`App::opts`]
